@@ -43,7 +43,17 @@ sub get_profile {
 
 # https://smartrow.fit/api/public-game
 sub get_workouts {
-    my $self = shift;
+}
+
+sub get_leaderboard {
+    my ( $self, %args ) = @_;
+
+    $args{distance} //= 2000;
+
+    my $params_string = '';
+    for my $key ( keys %args ) {
+        $params_string .= sprintf( "%s=%s&", $key, $args{$key} );
+    }
 
     my ( $user, $pass ) = $self->_credentials_via_env;
 
@@ -51,7 +61,8 @@ sub get_workouts {
               'https://'
             . $user . ':'
             . $pass . '@'
-            . 'smartrow.fit/api/public-game' );
+            . 'smartrow.fit/api/leaderboard?'
+            . $params_string );
 
     if ( !$response->{success} ) {
         return 'Response error';
@@ -59,7 +70,7 @@ sub get_workouts {
 
     my $json = decode_json $response->{content};
 
-    return $json;
+    return $json->[0];
 }
 
 sub _credentials_via_env {
@@ -75,6 +86,12 @@ sub _credentials_via_env {
 }
 
 
+
+
+
+
+
+
 1;
 
 __END__
@@ -89,7 +106,7 @@ WebService::SmartRow - Connect and get data from SmartRow API
 
 =head1 VERSION
 
-version 0.003
+version 0.004
 
  This module is a basic wrapper to allow Perl apps to access data from https://smartrow.fit
 
@@ -108,6 +125,8 @@ version 0.003
 
  If passing credentials via ENV you can simply use WebService::SmartRow->new;
 
+=head1 ATTRIBUTES
+
 =head2 http
 
   http is a HTTP::Tiny object by default, you can provide your own on construction.
@@ -128,6 +147,8 @@ version 0.003
 
   You can also set the SMARTROW_PASSWORD environment variable.
 
+=head1 METHODS
+
 =head2 get_profile
 
   This method obtains your profile information
@@ -136,6 +157,24 @@ version 0.003
 
   This method returns all the workouts you have done via SmartRow
 
+=head2 get_leaderboard
+
+  This method returns the data presented in the leaderboard (AKA Rankings page).
+
+  Unlike the first two methods, get_leaderboard can accept parameters to limit the data.
+
+  e.g.
+       my $leaderboard = $srv->get_leaderboard(
+           distance => 5000,  # Default if not provided to 2000, is mandatory
+           year     => 2022,
+           country  => 188,
+           age      => 'c',
+           gender   => 'f',
+           weight   => 'l',
+       );
+
+   More details on values able to be used to follow.
+
 =head1 AUTHOR
 
 Lance Wicks <lw@judocoach.com>
